# **DRÄGER CONTRIBUTOR LICENSE** AGREEMENT

At Dräger, we are keen on promoting Free and Open-Source Software (FOSS) —
both for our own use and the use in the FOSS Community. For Us and for You to
be certain what it means legally to contribute to one of our Projects, we are
required to have this Agreement in place. It governs the way We are allowed to
make use of your Contribution and the Project it is part of.

This is a legally binding document, so please read it carefully before agreeing
to it.

Please note that by convention We capitalize the first letter of each word that
is defined to have a specific meaning in this Agreement.

By submitting Your Contribution to Us or to a Subsidiary of Us, You accept and
agree to be bound to the following terms and conditions of this Agreement
regarding Your Contribution. This Agreements becomes effective when we accept
Your Contribution. Please note that We are under no obligation to use Your
Contribution or to continue to use a Contribution in any of our Projects.
Except for the license granted herein to Us and to the recipients of the
open-source software made available by Us or by our Subsidiaries and/or
Affiliates, You reserve all right, title, and interest in and to Your
Contributions.

## 1. Definitions

"**Dräger**", "**Us**" or "**We**" means Drägerwerk AG & Co. KGaA or any of our
Subsidiaries and/or Affiliates initiating or maintaining the open-source
software project You intend to provide Your Contribution to.

1.1  "**You**" (or "**Your**") shall mean the natural person or legal entity
entering into this Agreement with Us.

1.2  "**Copyright**" means all rights protecting works of authorship owned or
controlled by You or Your Affiliates, for the full term of their existence.

1.3  "**Affiliates**" means other legal entities that Control, are Controlled
by, or under common Control (with) a legal entity.

1.4  "**Subsidiaries**" means other legal entities that are controlled by a
legal entity whereas control means (i) the power, direct or indirect, to cause
the direction or management of such legal entity, whether by contract or
otherwise, (ii) ownership of fifty percent (50%) or more of the outstanding
shares or securities which vote to elect the management or other persons who
direct such legal entity or (iii) beneficial ownership of such entity.

1.5  "**Contribution**" means any original work of authorship, including any
modifications or additions to an existing work, in which You own that copyright
and that You Submit to Us for inclusion in the Project.

"**Project**" means the work of authorship which is made available by Us to
third parties which may or may not include Your Contribution.

1.6  "**Submission Date**" means the date on which You Submit a Contribution to
Us.

"**Submit**" means any form of electronic, verbal, or written communication
sent to Us, our Subsidiaries, Affiliates or our representatives, including but
not limited to electronic mailing lists, source code management systems, and
issue tracking systems that are managed by, or on behalf of, Us for the purpose
of discussing and improving the Project.

## 2. Grant of Copyright License.

You hereby grant to Us a perpetual,
worldwide, non-exclusive, no-charge, royalty-free, transferable, copyright
license to use the Contribution by all means, including, but not limited to,
reproduce, publish, modify, prepare derivative works of, publicly display,
publicly perform, sublicense, and distribute Your Contributions and such
derivative works. This includes all purposes, both commercial and
non-commercial activities.

## 3. Grant of Patent License.

You hereby grant to Us and to the recipients of the Project a perpetual,
worldwide, non-exclusive, no-charge, royalty-free, perpetual, transferable,
patent license to make, have made, use, offer to sell, sell, import, and
otherwise transfer the Project. This license applies to those patent claims
licensable by You or by Your Affiliates that are necessarily infringed by Your
Contribution(s) alone or by combination of Your Contribution(s) with the
Project to which such Contribution(s) was submitted and covers both patens that
are already acquired and those that are acquired hereafter.

## 4. Our Right to Enforce Infringement Claims.

You hereby authorize Us to assert claims in our name against third parties
arising from the infringement of Your Copyrights vested in the Contribution. To
the extent possible under applicable law, the right to assert claims applies to
all of Your claims resulting from the infringement of Your Copyrights,
including, without limitation, the right to demand the third party to cease and
desist the infringing use, to demand information regarding the infringement and
to destroy infringing products. You accept that We are under no obligation to
assert such claims against third parties violating Your Copyrights. Your right
to assert Your claims against third party infringers yourself remains
unaffected.

## 5. Representations

You represent that You are legally entitled to grant the above licenses. You
especially represent that each of Your Contributions is either Your original
creation or, if You are a legal entity, the original creation of Your (or of
Your Affiliates\') employees as part of their work for You (or for Your
Affiliate), or, if neither You nor (if You are a legal entity) Your employees
have created the Contribution as part of their work for You, that You are
authorized to Submit the Contribution and to grant the licenses set out herein
by the person or legal entity owning the rights to such Contribution. In case
You have created the Contribution as an employee and You submit it, You
represent that You are authorized by Your employer to submit the Contribution
and to grant to Us the licenses set out herein. You represent that the use of
Your Contribution is not subjected to any third-party license or other
restriction (including, but not limited to, related patents and trademarks --
patents and trademarks only those of which you are aware of) that would
restrict our ability to use Your Contribution as provided herein. You agree to
notify Us of any facts or circumstances of which you become aware that would
make these representations inaccurate in any respect.

## 6. Limitation of liability

TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, IN NO EVENT WILL YOU OR WE
BE LIABLE FOR ANY LOSS OF PROFITS, LOSS OF ANTICIPATED SAVINGS, LOSS OF DATA,
INDIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL AND EXEMPLARY DAMAGES ARISING OUT
OF THIS AGREEMENT REGARDLESS OF THE LEGAL OR EQUITABLE THEORY (CONTRACT, TORT
OR OTHERWISE) UPON WHICH THE CLAIM IS BASED.
